@@ -1,55 +1,62 @@
 #' Fit a trend surface to sky digital numbers
 #'
-#' Fit a trend surface using \code{\link[spatial]{surf.ls}} as workhorse
-#' function.
+#' Fit a trend surface using [spatial::surf.ls()] as workhorse function.
 #'
-#' This function is meant to be used after \code{\link{fit_coneshaped_model}}.
+#' This function is meant to be used after [fit_coneshaped_model()].
 #'
-#' A short explanation of this function can be found on
-#' \insertCite{Diaz2018;textual}{rcaiman}, under the heading \emph{Estimation of
-#' the sky DN as a previous step for our method}, after the explanation of the
-#' \code{\link{fit_coneshaped_model}}.
+#' This method was presented in \insertCite{Diaz2018;textual}{rcaiman}, under
+#' the heading *Estimation of the sky DN as a previous step for our method*. If
+#' you use this function in your research, please cite that paper in addition to
+#' this package (`citation("rcaiman"`).
 #'
-#' If you use this function in your research, please cite
-#' \insertCite{Diaz2018;textual}{rcaiman} in addition to this package.
 #'
 #' @inheritParams ootb_mblt
-#' @param filling_source \linkS4class{SpatRaster}. An actual or reconstructed
+#' @param filling_source [SpatRaster-class]. An actual or reconstructed
 #'   above-canopy image to complement the sky pixels detected through the gaps
-#'   of \code{r}. If an incomplete above-canopy image is available, non-sky
-#'   pixels should be turned \code{NA} or they will be considered as sky pixels
-#'   erroneously. A photograph taken immediately after or before taking \code{r}
-#'   under the open sky with the same equipment and configuration is a very good
-#'   option but not recommended under fleeting clouds. The orientation relative
-#'   to the North must be the same as for \code{r}. If it is set to \code{NULL}
-#'   (default), only sky pixels from \code{r} will be used as input.
+#'   of `r`. A photograph taken immediately after or before taking `r` under the
+#'   open sky with the same equipment and configuration is a very good option
+#'   but not recommended under fleeting clouds. The orientation relative to the
+#'   North must be the same as for `r`. If it is set to `NULL` (default), only
+#'   sky pixels from `r` will be used as input.
 #' @inheritParams spatial::surf.ls
 #'
-#' @return A list with an object of class \linkS4class{SpatRaster} and of class
-#'   \code{trls} (see \code{\link[spatial]{surf.ls}}).
+#' @note If an incomplete above-canopy image is available as filling source,
+#'   non-sky pixels should be turned `NA` or they will be erroneously considered
+#'   as sky pixels.
+#'
+#' @return A list with an object of class [SpatRaster-class] and of class `trls`
+#'   (see [spatial::surf.ls()]).
 #' @export
 #'
 #' @family Sky Reconstruction Functions
-#' @seealso \code{\link{thr_image}}
+#' @seealso [thr_mblt()]
 #'
 #' @references \insertAllCited{}
 #'
 #' @examples
 #' \dontrun{
-#' path <- system.file("external/DSCN4500.JPG", package = "rcaiman")
-#' caim <- read_caim(path, c(1280, 960) - 745, 745 * 2, 745 * 2)
-#' z <- zenith_image(ncol(caim), lens("Nikon_FCE9"))
+#' caim <- read_caim()
+#' r <- caim$Blue
+#' caim <- normalize(caim, 0, 20847, TRUE)
+#' z <- zenith_image(ncol(caim), lens())
 #' a <- azimuth_image(z)
-#' r <- gbc(caim$Blue)
+#' m <- !is.na(z)
+#'
+#' bin <- ootb_obia(caim, z, a, m, HSV(239, 0.85, 0.5), gamma = NULL)
+#'
 #' g <- sky_grid_segmentation(z, a, 10)
-#' bin <- find_sky_pixels(r, z, a)
-#' sky_points <- extract_sky_points(r, bin, g)
-#' sky_points <- extract_rl(r, z, a, sky_points, NULL)
-#' model <- fit_coneshaped_model(sky_points$sky_points)
+#' sky_points <- extract_sky_points(r, bin, g, dist_to_plant = 5)
+#' plot(bin)
+#' points(sky_points$col, nrow(caim) - sky_points$row, col = 2, pch = 10)
+#' rl <- extract_rl(r, z, a, sky_points)
+#'
+#' model <- fit_coneshaped_model(rl$sky_points)
+#' summary(model$model)
 #' sky_cs <- model$fun(z, a)
-#' m <- mask_hs(z, 0, 80)
-#' sky <- fit_trend_surface(r, z, a, bin, filling_source = sky_cs)
-#' plot(sky$image)
+#' persp(terra::aggregate(sky_cs, 10), theta = 90, phi = 45)
+#'
+#' sky_s <- fit_trend_surface(r, z, a, bin, sky_cs)
+#' persp(terra::aggregate(sky_s$image, 10), theta = 90, phi = 45)
 #' }
 fit_trend_surface <- function(r,
                               z,
@@ -93,7 +100,7 @@ fit_trend_surface <- function(r,
     terra::ext(out) <- terra::ext(x)
     out <- terra::resample(out, x)
 
-    list(image = out, fit = fit)
+    list(image = out, model = fit)
   }
   out <- .fit_trend_surface(r, np)
   out$image[is.na(z)] <- NA
