@@ -3,7 +3,14 @@
 }
 
 .get_gaussian_2d_parameters <- function(target_color, sigma) {
-  if (!is(target_color, "LAB")) target_color <- as(target_color, "LAB")
+  if (!is(target_color, "LAB")) {
+    if (is(target_color, "sRGB")) {
+      target_color <- as(target_color, "LAB")
+    } else {
+      target_color <- as(target_color, "sRGB")
+      target_color <- as(target_color, "LAB")
+    }
+  }
   ma <- colorspace::coords(target_color)
   target_a <- ma[, 2]
   target_b <- ma[, 3]
@@ -14,24 +21,25 @@
 #' Compute the membership to a target color
 #'
 #' This function was first presented in \insertCite{Diaz2015;textual}{rcaiman}.
-#' It computes the degree of membership to a color with two Gaussian membership
-#' functions and the dimensions \emph{a*} and \emph{b*} from the
-#' \emph{CIE L*a*b*} color space. To be clear, the lightness dimension is not
+#' It computes the degree of membership to a color using two Gaussian membership
+#' functions and the axes \emph{A} and \emph{B} from the
+#' \emph{CIE LAB} color space. The lightness dimension is not
 #' considered in the calculations.
 #'
 #' If you use this function in your research, please cite
-#' \insertCite{Diaz2015;textual}{rcaiman} in addition to this package.
+#' \insertCite{Diaz2015;textual}{rcaiman} in addition to this package
+#' (`citation("rcaiman"`).
 #'
 #' @inheritParams expand_noncircular
-#' @param target_color \linkS4class{color}.
-#' @param sigma Numeric vector of length one. Use \code{NULL} (default) to
-#'   estimate it automatically as the euclidean distance between
-#'   \code{target_color} and grey in the \emph{CIE L*a*b*} color space.
+#' @param target_color [color-class].
+#' @param sigma Numeric vector of length one. Use `NULL` (default) to estimate
+#'   it automatically as the euclidean distance between `target_color` and grey
+#'   in the \emph{CIE LAB} color space.
 #'
 #'
-#' @return It returns an object from the class \linkS4class{SpatRaster}. First
-#'   layer is the membership to the target color. Second layer is the membership
-#'   to grey. Both memberships are calculated with same \code{sigma}.
+#' @return It returns an object from the class [SpatRaster-class]. First layer
+#'   is the membership to the target color. Second layer is the membership to
+#'   grey. Both memberships are calculated with same `sigma`.
 #'
 #' @export
 #' @family Pre-processing Functions
@@ -40,11 +48,13 @@
 #'
 #' @examples
 #' \dontrun{
-#' caim <- read_caim()
-#' plot(caim)
-#' caim <- normalize(caim, 0, 255)
-#' z <- zenith_image(ncol(caim), lens("Nikon_FCE9"))
-#' mem <- membership_to_color(caim, sRGB(0.25, 0.75, 0))
+#' caim <- read_caim() %>% normalize
+#' z <- zenith_image(ncol(caim), lens())
+#' a <- azimuth_image(z)
+#' m <- !is.na(z)
+#'
+#' sky_blue <- HSV(239, 0.85, 0.5)
+#' mem <- membership_to_color(caim, sky_blue)
 #' plot(mem)
 #' }
 membership_to_color <- function(caim, target_color, sigma = NULL) {
@@ -56,7 +66,8 @@ membership_to_color <- function(caim, target_color, sigma = NULL) {
   if (!is.null(sigma)) stopifnot(length(sigma) == 1)
 
   color <- colorspace::sRGB(terra::values(caim))
-  if (!is(color, "LAB")) color <- as(color, "LAB")
+  color <- as(color, "LAB")
+
   p <- .get_gaussian_2d_parameters(target_color, sigma)
   max_z <- .gaussian2d(p[1], p[2], p[1], p[2], p[3])
   x <- colorspace::coords(color)
