@@ -4,40 +4,32 @@
 #'
 #' Methods currently implemented are:
 #'
-#' \itemize{
-#'
-#' \item \strong{Diaz2018}: method presented in
+#' * __Diaz2018__: method presented in
 #' \insertCite{Diaz2018;textual}{rcaiman} applied regionally. If this method is
-#' selected, the arguments \code{intercept}, \code{slope}, and \code{prob}
-#' should be provided. It works segment-wise extracting the digital numbers
-#' (dns) per segment and passing them to \code{quantile(dns, prob)}, which
-#' aggregated result (\code{x}) is in turn passed to \code{thr_image(x,
-#' intercept, slope)}. Finally, this threshold image is applied to obtain a
-#' binarized image.
-#'
-#' \item \strong{Methods from autothresholdr package}: this function can call
-#' methods from \code{\link[autothresholdr]{auto_thresh}}. Use \code{"IsoData"}
+#' selected, the arguments `intercept`, `slope`, and `prob` should be provided.
+#' It works segment-wise extracting the digital numbers per segment and passing
+#' them to [stats::quantile()] along with `prob`, which aggregated result is in
+#' turn passed to [thr_mblt()] along with `intercept` and `slope`. Finally, this
+#' threshold image is applied to obtain a binarized image.
+#' * __Methods from autothresholdr package__: this function can call
+#' methods from [autothresholdr::auto_thresh()]. For instance, use `"IsoData"`
 #' to use the algorithm by \insertCite{isodata;textual}{rcaiman}, which was
 #' recommended by \insertCite{Jonckheere2005;textual}{rcaiman}.
-#'
-#' \item \strong{Method isodata from this package}: Use \code{"thr_isodata"} to
-#' use \code{\link{thr_isodata}}.
-#'
-#' }
+#' * __Method isodata from this package__: Use `"thr_isodata"` to
+#' use [thr_isodata()].
 #'
 #' @inheritParams ootb_mblt
-#' @param segmentation \linkS4class{SpatRaster}. The result of segmenting
-#'   \code{r}. Probably, \code{\link{rings_segmentation}} will be the most used
-#'   for fisheye images.
+#' @param segmentation [SpatRaster-class]. The result of segmenting `r`.
+#'   Arguably, the result of a call to [rings_segmentation()] will be the
+#'   preferred choice for fisheye images.
 #' @param method Character vector of length one. See details for current
 #'   options.
-#' @inheritParams thr_image
+#' @inheritParams thr_mblt
 #' @inheritParams fit_trend_surface
-#' @param prob Numeric vector of length one. Probability for
-#'   \code{\link[stats]{quantile}} calculation.
+#' @param prob Numeric vector of length one. Probability for [stats::quantile()]
+#'   calculation.
 #'
-#' @return An object of class \linkS4class{SpatRaster} with values \code{0} and
-#'   \code{1}.
+#' @return An object of class [SpatRaster-class] with values `0` and `1`.
 #'
 #' @export
 #' @family Binarization Functions
@@ -48,15 +40,16 @@
 #' @examples
 #' \dontrun{
 #' path <- system.file("external/DSCN4500.JPG", package = "rcaiman")
-#' r <- read_caim(path, c(1280, 960) - 745, 745 * 2, 745 * 2)
-#' blue <- gbc(r$Blue)
-#' z <- zenith_image(ncol(r), lens("Nikon_FCE9"))
-#' rings <- rings_segmentation(z, 10)
-#' bin <- regional_thresholding(blue, rings, "Diaz2018", -8, 0.5, 1)
+#' caim <- read_caim(path, c(1250, 1020) - 745, 745 * 2, 745 * 2)
+#' z <- zenith_image(ncol(caim), lens("Nikon_FCE9"))
+#' r <- gbc(caim$Blue)
+#' r <- correct_vignetting(r, z, c(0.0638, -0.101)) %>% normalize()
+#' rings <- rings_segmentation(z, 15)
+#' bin <- regional_thresholding(r, rings, "Diaz2018", -7.8, 0.95 * 0.5, 0.99)
 #' plot(bin)
-#' bin <- regional_thresholding(blue, rings, "thr_isodata")
+#' bin <- regional_thresholding(r, rings, "thr_isodata")
 #' plot(bin)
-#' }
+#' #' }
 regional_thresholding <- function(r,
                                   segmentation,
                                   method,
@@ -81,7 +74,7 @@ regional_thresholding <- function(r,
   fun <- switch(method,
     Diaz2018 = function(dns) {
       dn <- quantile(dns, prob)
-      thr_image(dn, intercept, slope)
+      thr_mblt(dn, intercept, slope)
     },
     thr_isodata = thr_isodata
   )
